@@ -1,11 +1,12 @@
 package HTML::Template::Compiled::Parser;
+# $Id: Parser.pm 1154 2012-04-22 17:21:53Z tinita $
 use Carp qw(croak carp confess);
 use strict;
 use warnings;
 use base qw(Exporter);
 use HTML::Template::Compiled::Token qw(:tagtypes);
 use Scalar::Util;
-our $VERSION = '1.002_001'; # TRIAL VERSION
+our $VERSION = 0.14;
 my @vars;
 BEGIN {
 @vars = qw(
@@ -326,7 +327,7 @@ sub find_attributes {
         ]);
         push @{$arg->{tags}}, $token;
         if ($token->is_open &&
-            exists
+            not exists
                 $self->get_tagnames->{CLOSING_TAG()}->{ $arg->{name} }) {
             $arg->{level}++
         }
